@@ -313,7 +313,7 @@ pub(crate) fn to_alp(
             schema,
             apply,
             maintain_order,
-            dynamic_options,
+            options,
         } => {
             let i = to_alp(*input, expr_arena, lp_arena);
             let aggs_new = aggs.into_iter().map(|x| to_aexpr(x, expr_arena)).collect();
@@ -329,7 +329,7 @@ pub(crate) fn to_alp(
                 schema,
                 apply,
                 maintain_order,
-                dynamic_options,
+                options,
             }
         }
         LogicalPlan::Join {
@@ -776,7 +776,7 @@ pub(crate) fn node_to_lp(
             schema,
             apply,
             maintain_order,
-            dynamic_options,
+            options: dynamic_options,
         } => {
             let i = node_to_lp(input, expr_arena, lp_arena);
 
@@ -787,7 +787,7 @@ pub(crate) fn node_to_lp(
                 schema,
                 apply,
                 maintain_order,
-                dynamic_options,
+                options: dynamic_options,
             }
         }
         ALogicalPlan::Join {
