@@ -116,6 +116,7 @@ impl OptimizationRule for AggregatePushdown {
             CsvScan {
                 path,
                 schema,
+                output_schema,
                 options,
                 predicate,
                 aggregate,
@@ -126,6 +127,7 @@ impl OptimizationRule for AggregatePushdown {
                         CsvScan {
                             path,
                             schema,
+                            output_schema,
                             options,
                             predicate,
                             aggregate,
@@ -138,6 +140,7 @@ impl OptimizationRule for AggregatePushdown {
                     Some(ALogicalPlan::CsvScan {
                         path,
                         schema,
+                        output_schema,
                         options,
                         predicate,
                         aggregate,
@@ -148,11 +151,10 @@ impl OptimizationRule for AggregatePushdown {
             ParquetScan {
                 path,
                 schema,
-                with_columns,
+                output_schema,
                 predicate,
                 aggregate,
-                stop_after_n_rows,
-                cache,
+                options,
             } => match self.accumulated_projections.is_empty() {
                 true => {
                     lp_arena.replace(
@@ -160,11 +162,10 @@ impl OptimizationRule for AggregatePushdown {
                         ParquetScan {
                             path,
                             schema,
-                            with_columns,
+                            output_schema,
                             predicate,
                             aggregate,
-                            stop_after_n_rows,
-                            cache,
+                            options,
                         },
                     );
                     None
@@ -174,11 +175,10 @@ impl OptimizationRule for AggregatePushdown {
                     Some(ALogicalPlan::ParquetScan {
                         path,
                         schema,
-                        with_columns,
+                        output_schema,
                         predicate,
                         aggregate,
-                        stop_after_n_rows,
-                        cache,
+                        options,
                     })
                 }
             },
